@@ -39,7 +39,7 @@ class Result:
         """
         Return the Start time of the result
         """
-        return datetime.fromtimestamp(int(self.getResultTimestamp))
+        return datetime.fromtimestamp(int(self.getResultTimestamp(sample, resultID)))
         
     def __getSample(self, sample):
         """
