@@ -10,7 +10,7 @@ def getChunk(data, chunk):
         chunks += [len(data)]
         return data[chunks[chunk]+1:chunks[chunk+1]]
 
-def plotJV(res, hyst=False, ax=None):
+def plotJV(res, hyst=True, up=True, down=True, ax=None, **kargs):
     V = res['voltage'][0]
     I = res['current'][0]
 
@@ -21,7 +21,8 @@ def plotJV(res, hyst=False, ax=None):
         for i in range(2):
             Vx = getChunk(V,i)
             UP = Vx[0]<Vx[-1]
-            ax.plot(Vx, getChunk(I,i), label=["down","up"][UP])
+            if UP and up or not UP and down:
+                ax.plot(Vx, getChunk(I,i), label=["down","up"][UP])
     else:
         ax.plot(V, I)
     ax.set_xlabel("Voltage ["+res['voltage'][1]+"]")
